Learn R Programming

ICE (version 0.69)

ICHemophiliac: Hemophiliac Data Set

Description

Time (interval-censored) to onset of HIV infection.

Usage

data(ICHemophiliac)

Arguments

Format

a matrix with 2 columns. The first column contains the left endpoints of the intervals, and the second column contains the right endpoints.